@@ -5,12 +5,6 @@ import logging
 import time
 from collections import OrderedDict
 
-from pysecspy.const import (
-    RECORDING_TYPE_CONTINUOUS,
-    RECORDING_TYPE_MOTION,
-    RECORDING_TYPE_OFF,
-)
-
 _LOGGER = logging.getLogger(__name__)
 
 CAMERA_KEYS = {
@@ -68,10 +62,13 @@ def process_camera(server_id, server_credential, camera, include_events):
     else:
         recording_mode_m = camera["mode-m"] == "armed"
     # Live Image
-    base_stream = f"rtsp://{server_credential['host']}:{server_credential['port']}/stream?auth={server_credential['token']}"
-    # live_stream = f"{base_stream}&cameraNum={camera_id}&codec=h264&width=1920&height=1080&req_fps=25"
-    live_stream = f"{base_stream}&cameraNum={camera_id}"
-
+    base_url = f"{server_credential['host']}:{server_credential['port']}"
+    base_stream = f"rtsp://{base_url}/stream?auth={server_credential['token']}"
+    live_stream = f"{base_stream}&cameraNum={camera_id}&codec=h264"
+    # Jpeg Image
+    image_width = str(camera["width"])
+    image_height = str(camera["height"])
+    latest_image = f"http://{base_url}/image?auth={server_credential['token']}&cameraNum={camera_id}&width={image_width}&height={image_height}&quality=75"
     # Other Settings
     ip_address = "Local" if camera["devicetype"] == "Local" else camera.get("address")
 
@@ -85,8 +82,9 @@ def process_camera(server_id, server_credential, camera, include_events):
         "recording_mode_m": recording_mode_m,
         "ip_address": ip_address,
         "live_stream": live_stream,
-        "width": str(camera["width"]),
-        "height": str(camera["height"]),
+        "latest_image": latest_image,
+        "image_width": image_width,
+        "image_height": image_height,
         "fps": str(camera["current-fps"]),
         "video_format": str(camera["video-format"]),
     }
@@ -97,7 +95,9 @@ def process_camera(server_id, server_credential, camera, include_events):
         # Get the last time motion occured
         if camera.get("timesincelastmotion") is not None:
             last_update = int(time.time()) + int(camera["timesincelastmotion"])
-            camera_update["last_motion"] = datetime.datetime.fromtimestamp(last_update / 1000).strftime("%Y-%m-%d %H:%M:%S")
+            camera_update["last_motion"] = datetime.datetime.fromtimestamp(
+                last_update / 1000
+            ).strftime("%Y-%m-%d %H:%M:%S")
         else:
             camera_update["last_motion"] = None
 
