@@ -46,12 +46,14 @@ class SecSpyServer:
         port: int,
         username: str,
         password: str,
+        use_ssl: bool = False, 
     ):
         self._host = host
         self._port = port
         self._username = username
         self._password = password
-        self._base_url = f"http://{host}:{port}"
+        self._use_ssl = use_ssl
+        self._base_url = f"https://{host}:{port}" if self._use_ssl else f"http://{host}:{port}"
         self._token = b64encode(
             bytes(f"{self._username}:{self._password}", "utf-8")
         ).decode()
@@ -172,10 +174,12 @@ class SecSpyServer:
         json_raw = xmltodict.parse(data)
         json_response = pjson.loads(pjson.dumps(json_raw))
         nvr = json_response["system"]["server"]
-        sched_preset = json_response["system"]["schedulepresetlist"]
+        sys_info = json_response["system"]
+        sched_preset = sys_info.get("schedulepresetlist")        
         presets = []
-        for preset in sched_preset["schedulepreset"]:
-            presets.append(preset)
+        if sched_preset is not None:
+            for preset in sched_preset["schedulepreset"]:
+                presets.append(preset)
 
         return {
             SERVER_NAME: nvr["server-name"],
@@ -354,6 +358,9 @@ class SecSpyServer:
                 await asyncio.sleep(0)
         except client_exceptions.ClientConnectionError:
             return
+        except Exception as ed:
+            _LOGGER.debug("Unhandled error: %s", ed)
+            return
         finally:
             _LOGGER.debug("stream disconnected")
             self.ws_connection = None
@@ -508,7 +515,7 @@ class SecSpyServer:
 
         if (
             not processed_camera["recording_mode_m"]
-            or not processed_camera["recording_mode_c"]
+            and not processed_camera["recording_mode_c"]
         ):
             processed_event = camera_event_from_ws_frames(
                 self._device_state_machine, action_json, data_json
